@@ -112,6 +112,7 @@ sub options {
     local @ARGV = @_;
     my $opt = do {
 	    require File::Rename::Options; 
+	    File::Rename::Options->import;
 	    File::Rename::Options::GetOptions(1);
     };
     die "Bad options '@_'" unless $opt;
@@ -123,14 +124,16 @@ sub is_windows {
     unless ( $] < 5.014 ) {
 	if ( eval { require Perl::OSType; } ) { 
             return Perl::OSType::is_os_type('Windows'); 
-	}
-	diag $@;
+        }
+        diag $@;
     }
-    return ($^O =~ m{Win}) 
+    return ($^O eq q{MSWin32} or $^O eq q{cygwin}) 
 } 
 
 sub script_name {
     return +(is_windows() ? 'file-rename' : 'rename');
 }
 
+sub unsafe_script_name { return 'unsafe-rename'; }
+
 1;
